@@ -15,32 +15,69 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#ifdef _WIN32
+#include "win32/config.h"
+#else
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include <limits.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
+#ifdef HAVE_STDDEF_H
+#include <stddef.h>
+#endif
 #ifdef HAVE_STDARG_H
 #include <stdarg.h>
 #endif
 #include <sys/stat.h>
+#ifdef __APPLE_API_PRIVATE
+#undef __APPLE_API_PRIVATE
+#endif
+#if HAVE_DIRENT_H
+# include <dirent.h>
+# define NAMLEN(dirent) strlen((dirent)->d_name)
+#else
+# if HAVE_SYS_DIRENT_H
+#  include <sys/dirent.h>
+#  define NAMLEN(dirent) strlen((dirent)->d_name)
+# else
+#  define dirent direct
+#  define NAMLEN(dirent) (dirent)->d_namlen
+#  if HAVE_SYS_NDIR_H
+#   include <sys/ndir.h>
+#  endif
+#  if HAVE_SYS_DIR_H
+#   include <sys/dir.h>
+#  endif
+#  if HAVE_NDIR_H
+#   include <ndir.h>
+#  endif
+# endif
+#endif
 
-/*#include <X11/Xlib.h>*/
 #ifdef _WIN32
-#include "win32/config.h"
 #include "win32/afterbase.h"
 #include <io.h>
 #include <windows.h>
 #define access _access
 #else
-#include "config.h"
 #include "afterbase.h"
 #endif
 
+#ifdef X_DISPLAY_MISSING
+#include "colornames.h"
+#endif
+
+/*#include <X11/Xlib.h>*/
+
 Display *dpy = NULL ;
 char    *asim_ApplicationName = NULL ;
 
@@ -155,7 +192,7 @@ void asim_nonGNUC_debugout( const char *format, ...)
     fprintf (stderr, "\n" );
 }
 
-inline void asim_nonGNUC_debugout_stub( const char *format, ...)
+void asim_nonGNUC_debugout_stub( const char *format, ...)
 {}
 
 /* from libAfterBase/fs.c : */
@@ -204,26 +241,38 @@ asim_put_file_home (const char *path_with_home)
 }
 
 char*
-asim_load_file(const char* realfilename)
+asim_load_binary_file(const char* realfilename, long *file_size_return)
 {
 	struct stat st;
 	FILE* fp;
-	char* str;
-	int len;
+	char* data = NULL ;
 
 	/* Get the file size. */
 	if (stat(realfilename, &st)) return NULL;
-
 	/* Open the file. */
 	fp = fopen(realfilename, "rb");
-	if (!(fp = fopen(realfilename, "rb"))) return NULL;
+	if ( fp != NULL ) 
+	{
+		long len ; 
+		/* Read in the file. */
+		data = safemalloc(st.st_size + 1);
+		len = fread(data, 1, st.st_size, fp);
+		if( file_size_return ) 
+			*file_size_return = len ; 
+		fclose(fp);
+	}
+	return data;
+}
 
-	/* Read in the file. */
-	str = NEW_ARRAY(char, st.st_size + 1);
-	len = fread(str, 1, st.st_size, fp);
-	if (len >= 0) str[len] = '\0';
+char*
+asim_load_file(const char* realfilename)
+{
+	long len;
+	char* str = load_binary_file( realfilename, &len );
+
+	if (str != NULL && len >= 0) 
+		str[len] = '\0';
 
-	fclose(fp);
 	return str;
 }
 
@@ -258,6 +307,7 @@ asim_find_file (const char *file, const char *pathlist, int type)
 	int            max_path = 0;
 	register char *ptr;
 	register int   i;
+	Bool local = False ;
 
 	if (file == NULL)
 		return NULL;
@@ -268,8 +318,14 @@ asim_find_file (const char *file, const char *pathlist, int type)
 #define PATH_SEPARATOR_CHAR ':'
 #define PATH_CHAR '/'
 #endif
-
+	
 	if (*file == PATH_CHAR || *file == '~' || ((pathlist == NULL) || (*pathlist == '\0')))
+		local = True ;
+	else if( file[0] == '.' && (file[1] == PATH_CHAR || (file[1] == '.' && file[2] == PATH_CHAR))) 
+		local = True ;
+	else if( strncmp( file, "$HOME", 5) == 0 ) 
+		local = True ;
+	if( local ) 
 	{
 		path = put_file_home (file);
 		if ( access (path, type) == 0 )
@@ -433,6 +489,26 @@ asim_mystrndup (const char *str, size_t n)
 	return c;
 }
 
+#ifdef X_DISPLAY_MISSING
+static int compare_xcolor_entries(const void *a, const void *b)
+{
+   return strcmp((const char *) a, ((const XColorEntry *) b)->name);
+}
+
+static int FindColor(const char *name, CARD32 *colorPtr)
+{
+   XColorEntry *found;
+
+   found = bsearch(name, xColors, numXColors, sizeof(XColorEntry),
+                   compare_xcolor_entries);
+   if (found == NULL)
+      return 0;
+
+   *colorPtr = 0xFF000000|((found->red<<16)&0x00FF0000)|((found->green<<8)&0x0000FF00)|((found->blue)&0x000000FF);
+   return 1;
+}
+#endif
+
 /*******************************************************************/
 /* from parse,c : */
 const char *asim_parse_argb_color( const char *color, CARD32 *pargb )
@@ -488,6 +564,13 @@ const char *asim_parse_argb_color( const char *color, CARD32 *pargb )
 		}else if( *color )
 		{
 			/* does not really matter here what screen to use : */
+#ifdef X_DISPLAY_MISSING
+			register const char *ptr = &(color[0]);
+            if(!FindColor(color, pargb))
+                return color;
+    		while( !isspace((int)*ptr) && *ptr != '\0' ) ptr++;
+			return ptr;
+#else
 			if( dpy == NULL )
 				return color ;
 			else
@@ -503,6 +586,7 @@ const char *asim_parse_argb_color( const char *color, CARD32 *pargb )
 				while( !isspace((int)*ptr) && *ptr != '\0' ) ptr++;
 				return ptr;
 			}
+#endif
 		}
 	}
 	return color;
@@ -806,12 +890,10 @@ asim_string_compare (ASHashableValue value1, ASHashableValue value2)
 }
 
 void
-asim_string_destroy (ASHashableValue value, void *data)
+asim_string_destroy_without_data (ASHashableValue value, void *data)
 {
 	if ((char*)value != NULL)
 		free ((char*)value);
-	if (data != (void*)value && data != NULL)
-		free (data);
 }
 
 /* variation for case-unsensitive strings */
@@ -996,3 +1078,64 @@ asim_wait_tick ()
 #endif
 }
 
+#ifndef _WIN32
+/*
+ * Non-NULL select and dcomp pointers are *NOT* tested, but should be OK.
+ * They are not used by afterstep however, so this implementation should
+ * be good enough.
+ *
+ * c.ridd@isode.com
+ */
+int
+asim_my_scandir_ext ( const char *dirname, int (*filter_func) (const char *),
+				 Bool (*handle_direntry_func)( const char *fname, const char *fullname, struct stat *stat_info, void *aux_data), 
+				 void *aux_data)
+{
+	DIR          *d;
+	struct dirent *e;						   /* Pointer to static struct inside readdir() */
+	int           n = 0;					   /* Count of nl used so far */
+	char         *filename;					   /* For building filename to pass to stat */
+	char         *p;						   /* Place where filename starts */
+	struct stat   stat_info;
+
+	d = opendir (dirname);
+
+	if (d == NULL)
+		return -1;
+
+	filename = (char *)safemalloc (strlen (dirname) + PATH_MAX + 2);
+	if (filename == NULL)
+	{
+		closedir (d);
+		return -1;
+	}
+	strcpy (filename, dirname);
+	p = filename + strlen (filename);
+	if( *p != '/' )
+	{	
+		*p++ = '/';
+		*p = 0;									   /* Just in case... */
+	}
+	
+	while ((e = readdir (d)) != NULL)
+	{
+		if ((filter_func == NULL) || filter_func (&(e->d_name[0])))
+		{
+			/* Fill in the fields using stat() */
+			strcpy (p, e->d_name);
+			if (stat (filename, &stat_info) != -1)
+			{	
+				if( handle_direntry_func( e->d_name, filename, &stat_info, aux_data) )
+					n++;
+			}
+		}
+	}
+	free (filename);
+
+	if (closedir (d) == -1)
+		return -1;
+	/* Return the count of the entries */
+	return n;
+}
+
+#endif
