@@ -55,6 +55,10 @@ extern "C" {
 struct SyntaxDef;
 struct TermDef;
 struct ASSession;
+struct ASDesktopCategory;
+struct ASDesktopEntry;
+struct ASCategoryTree;
+struct ASDatabase;
 
 /* compatibility macros : */
 #define GetFdWidth          get_fd_width
@@ -121,11 +125,26 @@ int   match_command_line_opt( char *argvi, CommandLineOpts *options );
 void  handler_show_info( char *argv, void *trg, long param );
 void  handler_set_flag( char *argv, void *trg, long param );
 void  handler_set_string( char *argv, void *trg, long param );
+void  handler_set_dup_string( char *argv, void *trg, long param );
 void  handler_set_int( char *argv, void *trg, long param );
 void  handler_set_geometry( char *argv, void *trg, long param );
 void  handler_set_gravity( char *argv, void *trg, long param );
 
 
+#define ASXMLVAR_IconButtonWidth 		"icon.button.width"
+#define ASXMLVAR_IconButtonHeight		"icon.button.height"
+#define ASXMLVAR_IconWidth				"icon.width"
+#define ASXMLVAR_IconHeight				"icon.height"
+#define ASXMLVAR_MinipixmapWidth		"minipixmap.width"
+#define ASXMLVAR_MinipixmapHeight		"minipixmap.height"
+#define ASXMLVAR_TitleFontSize			"title.font.size"
+#define ASXMLVAR_MenuFontSize			"menu.font.size"
+#define ASXMLVAR_MenuShowMinipixmaps 	"menu.show_minipixmaps"
+#define ASXMLVAR_MenuShowUnavailable 	"menu.show_unavailable"
+#define ASXMLVAR_MenuTxtItemsInd		"menu.texture_items_individualy"
+#define ASXMLVAR_MenuRecentSubmenuItems "menu.recent_submenu_items"
+
+
 typedef struct ASProgArgs
 {
 	/* backup of the cmdline : */
@@ -169,8 +188,20 @@ typedef struct ASProgArgs
 
 }ASProgArgs;
 
+typedef enum ASToolType
+{
+	ASTool_Term = 0,
+	ASTool_Browser,
+	ASTool_Editor,	
+	ASTool_Count	  
+}ASToolType;
+
 typedef struct ASEnvironment
 {
+#define ASE_NoSharedMemory			(0x01<<0)
+#define ASE_NoKDEGlobalsTheming		(0x01<<1)
+  ASFlagType flags ; 
+
   char *module_path;
   char *audio_path;
   char *icon_path;
@@ -180,7 +211,14 @@ typedef struct ASEnvironment
   unsigned short desk_pages_h, desk_pages_v ;
   unsigned short desk_scale ;
 
-  char *term_command ;
+	enum{ ASE_AllowModuleNameCollision = 0,
+		  ASE_KillOldModuleOnNameCollision,	
+		  ASE_KillNewModuleOnNameCollision 
+		}module_name_collision ; 
+  char *tool_command[ASTool_Count] ;
+  
+  char *gtkrc_path ;
+  char *gtkrc20_path ;
 }ASEnvironment;
 
 /*
@@ -194,6 +232,7 @@ typedef struct ASEnvironment
 
 
 ASEnvironment *make_default_environment();
+void set_environment_tool_from_list( ASEnvironment *e, ASToolType type, char ** list, int list_len );
 void destroy_asenvironment( ASEnvironment **penv );
 
 /***********************************************************************************/
@@ -228,8 +267,13 @@ void InitMyApp (  const char *app_class, int agrc, char **argv, void (*version_f
 void SetMyName (char *argv0);
 /* overrides envvars supplied on startup : */
 void override_environ( char **envp );
+void destroy_asdatabase();
 
+struct ASDesktopCategory* name2desktop_category( const char *name, struct ASCategoryTree **tree_return );
+struct ASDesktopEntry* name2desktop_entry( const char *name, struct ASCategoryTree **tree_return );
+									
 
+void free_as_app_args();
 void FreeMyAppResources();
 
 void InitSession();
@@ -298,6 +342,14 @@ struct TermDef  *func2fterm (enum FunctionCode func, int quiet);
 
 extern struct ASSession *Session;          /* filenames of look, feel and background */
 extern struct ASEnvironment *Environment;
+extern struct ASDatabase    *Database;
+
+extern struct ASCategoryTree *StandardCategories ;
+extern struct ASCategoryTree *AfterStepCategories ;
+extern struct ASCategoryTree *KDECategories ;
+extern struct ASCategoryTree *GNOMECategories ;
+extern struct ASCategoryTree *OtherCategories ;
+extern struct ASCategoryTree *CombinedCategories ;
 
 /* this two are unused in as-stable yet : */
 struct ASFeel;
